You are viewing a plain text version of this content. The canonical link for it is here.
Posted to scm@geronimo.apache.org by jd...@apache.org on 2008/10/05 15:08:46 UTC

svn commit: r701789 - in /geronimo/gshell/trunk: gshell-support/gshell-vfs-meta/src/main/java/org/apache/geronimo/gshell/vfs/provider/meta/ gshell-wisdom/gshell-wisdom-core/src/main/java/org/apache/geronimo/gshell/wisdom/meta/ gshell-wisdom/gshell-wisd...

Author: jdillon
Date: Sun Oct  5 06:08:45 2008
New Revision: 701789

URL: http://svn.apache.org/viewvc?rev=701789&view=rev
Log:
Added MetaDataContent intf to help abstract the dynamic content stuff from the file/data its bound to
Added MapContentSupport to help render MetaDataContents which are map-based
Added meta:/system/runtime to display muck from java.lang.Runtime

Added:
    geronimo/gshell/trunk/gshell-support/gshell-vfs-meta/src/main/java/org/apache/geronimo/gshell/vfs/provider/meta/MetaDataContent.java   (contents, props changed)
      - copied, changed from r701779, geronimo/gshell/trunk/gshell-support/gshell-vfs-meta/src/main/java/org/apache/geronimo/gshell/vfs/provider/meta/MetaDataRegistry.java
    geronimo/gshell/trunk/gshell-wisdom/gshell-wisdom-core/src/main/java/org/apache/geronimo/gshell/wisdom/meta/MapContentSupport.java   (with props)
    geronimo/gshell/trunk/gshell-wisdom/gshell-wisdom-core/src/main/java/org/apache/geronimo/gshell/wisdom/meta/RuntimeContent.java   (with props)
    geronimo/gshell/trunk/gshell-wisdom/gshell-wisdom-core/src/main/java/org/apache/geronimo/gshell/wisdom/meta/SystemEnvironmentContent.java   (with props)
    geronimo/gshell/trunk/gshell-wisdom/gshell-wisdom-core/src/main/java/org/apache/geronimo/gshell/wisdom/meta/SystemPropertiesContent.java   (contents, props changed)
      - copied, changed from r701779, geronimo/gshell/trunk/gshell-wisdom/gshell-wisdom-core/src/main/java/org/apache/geronimo/gshell/wisdom/meta/SystemPropertiesMetaData.java
Removed:
    geronimo/gshell/trunk/gshell-wisdom/gshell-wisdom-core/src/main/java/org/apache/geronimo/gshell/wisdom/meta/SystemPropertiesMetaData.java
Modified:
    geronimo/gshell/trunk/gshell-support/gshell-vfs-meta/src/main/java/org/apache/geronimo/gshell/vfs/provider/meta/MetaData.java
    geronimo/gshell/trunk/gshell-support/gshell-vfs-meta/src/main/java/org/apache/geronimo/gshell/vfs/provider/meta/MetaDataRegistryConfigurer.java
    geronimo/gshell/trunk/gshell-wisdom/gshell-wisdom-core/src/main/java/org/apache/geronimo/gshell/wisdom/meta/MetaDataInstaller.java
    geronimo/gshell/trunk/gshell-wisdom/gshell-wisdom-core/src/main/java/org/apache/geronimo/gshell/wisdom/registry/CommandResolverImpl.java
    geronimo/gshell/trunk/gshell-wisdom/gshell-wisdom-core/src/main/resources/META-INF/spring/components.xml

Modified: geronimo/gshell/trunk/gshell-support/gshell-vfs-meta/src/main/java/org/apache/geronimo/gshell/vfs/provider/meta/MetaData.java
URL: http://svn.apache.org/viewvc/geronimo/gshell/trunk/gshell-support/gshell-vfs-meta/src/main/java/org/apache/geronimo/gshell/vfs/provider/meta/MetaData.java?rev=701789&r1=701788&r2=701789&view=diff
==============================================================================
--- geronimo/gshell/trunk/gshell-support/gshell-vfs-meta/src/main/java/org/apache/geronimo/gshell/vfs/provider/meta/MetaData.java (original)
+++ geronimo/gshell/trunk/gshell-support/gshell-vfs-meta/src/main/java/org/apache/geronimo/gshell/vfs/provider/meta/MetaData.java Sun Oct  5 06:08:45 2008
@@ -47,18 +47,30 @@
     
     private final FileType type;
 
-    private long lastModified = -1;
+    private final MetaDataContent content;
 
-    private final Map<String,Object> attributes = /*Collections.synchronizedMap(*/new HashMap<String,Object>()/*)*/;
+    private final Map<String,Object> attributes = new HashMap<String,Object>();
 
-    private final Collection<MetaData> children = /*Collections.synchronizedCollection(*/new ArrayList<MetaData>()/*)*/;
+    private final Collection<MetaData> children = new ArrayList<MetaData>();
 
-    public MetaData(final FileName name, final FileType type) {
+    private long lastModified = -1;
+    
+    public MetaData(final FileName name, final FileType type, final MetaDataContent content) {
         assert name != null;
         assert type != null;
+        // content may be null
 
         this.name = name;
         this.type = type;
+        this.content = content;
+    }
+
+    public MetaData(final FileName name, final FileType type) {
+        this(name, type, null);
+    }
+
+    public MetaData(final FileName name, final MetaDataContent content) {
+        this(name, FileType.FILE, content);
     }
 
     public FileName getName() {
@@ -70,7 +82,7 @@
     }
 
     public byte[] getBuffer() {
-        return null;
+        return content != null ? content.getBuffer() : null;
     }
 
     public void updateLastModified() {

Copied: geronimo/gshell/trunk/gshell-support/gshell-vfs-meta/src/main/java/org/apache/geronimo/gshell/vfs/provider/meta/MetaDataContent.java (from r701779, geronimo/gshell/trunk/gshell-support/gshell-vfs-meta/src/main/java/org/apache/geronimo/gshell/vfs/provider/meta/MetaDataRegistry.java)
URL: http://svn.apache.org/viewvc/geronimo/gshell/trunk/gshell-support/gshell-vfs-meta/src/main/java/org/apache/geronimo/gshell/vfs/provider/meta/MetaDataContent.java?p2=geronimo/gshell/trunk/gshell-support/gshell-vfs-meta/src/main/java/org/apache/geronimo/gshell/vfs/provider/meta/MetaDataContent.java&p1=geronimo/gshell/trunk/gshell-support/gshell-vfs-meta/src/main/java/org/apache/geronimo/gshell/vfs/provider/meta/MetaDataRegistry.java&r1=701779&r2=701789&rev=701789&view=diff
==============================================================================
--- geronimo/gshell/trunk/gshell-support/gshell-vfs-meta/src/main/java/org/apache/geronimo/gshell/vfs/provider/meta/MetaDataRegistryConfigurer.java (original)
+++ geronimo/gshell/trunk/gshell-support/gshell-vfs-meta/src/main/java/org/apache/geronimo/gshell/vfs/provider/meta/MetaDataRegistryConfigurer.java Sun Oct  5 06:08:45 2008
@@ -97,6 +97,18 @@
         return addFolder(parseName(name));
     }
 
+    public MetaData addContent(final FileName name, final MetaDataContent content) {
+        assert name != null;
+        assert content != null;
+
+        MetaData data = new MetaData(name, content);
+        return add(name, data);
+    }
+
+    public MetaData addContent(final String name, final MetaDataContent content) {
+        return addContent(parseName(name), content);
+    }
+
     //
     // TODO: Add remove methods, and nested namespace muck, once we get base stuff working in the parser
     //

Added: geronimo/gshell/trunk/gshell-wisdom/gshell-wisdom-core/src/main/java/org/apache/geronimo/gshell/wisdom/meta/MapContentSupport.java
URL: http://svn.apache.org/viewvc/geronimo/gshell/trunk/gshell-wisdom/gshell-wisdom-core/src/main/java/org/apache/geronimo/gshell/wisdom/meta/MapContentSupport.java?rev=701789&view=auto
==============================================================================
--- geronimo/gshell/trunk/gshell-wisdom/gshell-wisdom-core/src/main/java/org/apache/geronimo/gshell/wisdom/meta/MapContentSupport.java (added)
+++ geronimo/gshell/trunk/gshell-wisdom/gshell-wisdom-core/src/main/java/org/apache/geronimo/gshell/wisdom/meta/MapContentSupport.java Sun Oct  5 06:08:45 2008
@@ -0,0 +1,56 @@
+/*
+ * Licensed to the Apache Software Foundation (ASF) under one
+ * or more contributor license agreements.  See the NOTICE file
+ * distributed with this work for additional information
+ * regarding copyright ownership.  The ASF licenses this file
+ * to you under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance
+ * with the License.  You may obtain a copy of the License at
+ *
+ *  http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ * KIND, either express or implied.  See the License for the
+ * specific language governing permissions and limitations
+ * under the License.
+ */
+
+package org.apache.geronimo.gshell.wisdom.meta;
+
+import org.apache.geronimo.gshell.vfs.provider.meta.MetaDataContent;
+
+import java.io.ByteArrayOutputStream;
+import java.io.IOException;
+import java.io.StringWriter;
+import java.io.PrintWriter;
+import java.util.Properties;
+import java.util.Map;
+
+/**
+ * Support for {@link MetaDataContent} generated for a {@link Map}.
+ *
+ * @version $Rev$ $Date$
+ */
+public abstract class MapContentSupport<K,V>
+    implements MetaDataContent
+{
+    public byte[] getBuffer() {
+        StringWriter writer = new StringWriter();
+        PrintWriter out = new PrintWriter(writer);
+
+        for (Map.Entry<K,V> entry : getMap().entrySet()) {
+            out.print(entry.getKey());
+            out.print("=");
+            out.println(entry.getValue());
+        }
+
+        out.flush();
+        out.close();
+
+        return writer.toString().getBytes();
+    }
+
+    protected abstract Map<K,V> getMap();
+}
\ No newline at end of file

Propchange: geronimo/gshell/trunk/gshell-wisdom/gshell-wisdom-core/src/main/java/org/apache/geronimo/gshell/wisdom/meta/MapContentSupport.java
------------------------------------------------------------------------------
    svn:eol-style = native

Propchange: geronimo/gshell/trunk/gshell-wisdom/gshell-wisdom-core/src/main/java/org/apache/geronimo/gshell/wisdom/meta/MapContentSupport.java
------------------------------------------------------------------------------
    svn:keywords = Date Author Id Revision HeadURL

Propchange: geronimo/gshell/trunk/gshell-wisdom/gshell-wisdom-core/src/main/java/org/apache/geronimo/gshell/wisdom/meta/MapContentSupport.java
------------------------------------------------------------------------------
    svn:mime-type = text/plain

Modified: geronimo/gshell/trunk/gshell-wisdom/gshell-wisdom-core/src/main/java/org/apache/geronimo/gshell/wisdom/meta/MetaDataInstaller.java
URL: http://svn.apache.org/viewvc/geronimo/gshell/trunk/gshell-wisdom/gshell-wisdom-core/src/main/java/org/apache/geronimo/gshell/wisdom/meta/MetaDataInstaller.java?rev=701789&r1=701788&r2=701789&view=diff
==============================================================================
--- geronimo/gshell/trunk/gshell-wisdom/gshell-wisdom-core/src/main/java/org/apache/geronimo/gshell/wisdom/meta/MetaDataInstaller.java (original)
+++ geronimo/gshell/trunk/gshell-wisdom/gshell-wisdom-core/src/main/java/org/apache/geronimo/gshell/wisdom/meta/MetaDataInstaller.java Sun Oct  5 06:08:45 2008
@@ -22,16 +22,9 @@
 import org.apache.geronimo.gshell.vfs.provider.meta.MetaData;
 import org.apache.geronimo.gshell.vfs.provider.meta.MetaDataRegistry;
 import org.apache.geronimo.gshell.vfs.provider.meta.MetaDataRegistryConfigurer;
-import org.apache.commons.vfs.FileName;
-import org.apache.commons.vfs.FileType;
 import org.springframework.beans.factory.annotation.Autowired;
 
 import javax.annotation.PostConstruct;
-import java.io.ByteArrayOutputStream;
-import java.io.IOException;
-import java.util.Properties;
-import java.util.Map;
-import java.util.LinkedHashMap;
 
 /**
  * Installs {@link MetaData} into the {@link MetaDataRegistry}.
@@ -43,8 +36,6 @@
     @Autowired
     private MetaDataRegistry metaRegistry;
 
-    // private MetaDataRegistryConfigurer metaConfig;
-
     @PostConstruct
     public void init() throws Exception {
         assert metaRegistry != null;
@@ -52,7 +43,12 @@
 
         // HACK: Hard code this for now, evetually configure via spring
         metaConfig.addFolder("/system");
-        FileName name = metaConfig.getNameParser().parseUri("/system/properties");
-        metaConfig.add(name, new SystemPropertiesMetaData(name));
+        metaConfig.addContent("/system/runtime", new RuntimeContent());
+        metaConfig.addContent("/system/properties", new SystemPropertiesContent());
+        metaConfig.addContent("/system/environment", new SystemEnvironmentContent());
+
+        //
+        // TODO: Add /system/threads
+        //
     }
 }
\ No newline at end of file

Added: geronimo/gshell/trunk/gshell-wisdom/gshell-wisdom-core/src/main/java/org/apache/geronimo/gshell/wisdom/meta/RuntimeContent.java
URL: http://svn.apache.org/viewvc/geronimo/gshell/trunk/gshell-wisdom/gshell-wisdom-core/src/main/java/org/apache/geronimo/gshell/wisdom/meta/RuntimeContent.java?rev=701789&view=auto
==============================================================================
--- geronimo/gshell/trunk/gshell-wisdom/gshell-wisdom-core/src/main/java/org/apache/geronimo/gshell/wisdom/meta/RuntimeContent.java (added)
+++ geronimo/gshell/trunk/gshell-wisdom/gshell-wisdom-core/src/main/java/org/apache/geronimo/gshell/wisdom/meta/RuntimeContent.java Sun Oct  5 06:08:45 2008
@@ -0,0 +1,48 @@
+/*
+ * Licensed to the Apache Software Foundation (ASF) under one
+ * or more contributor license agreements.  See the NOTICE file
+ * distributed with this work for additional information
+ * regarding copyright ownership.  The ASF licenses this file
+ * to you under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance
+ * with the License.  You may obtain a copy of the License at
+ *
+ *  http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ * KIND, either express or implied.  See the License for the
+ * specific language governing permissions and limitations
+ * under the License.
+ */
+
+package org.apache.geronimo.gshell.wisdom.meta;
+
+import org.apache.geronimo.gshell.vfs.provider.meta.MetaDataContent;
+
+import java.io.PrintWriter;
+import java.io.StringWriter;
+import java.util.Map;
+import java.util.LinkedHashMap;
+
+/**
+ * {@link MetaDataContent} to return details about {@link Runtime}.
+ *
+ * @version $Rev$ $Date$
+ */
+public class RuntimeContent
+    extends MapContentSupport<String,Object>
+{
+    protected Map<String, Object> getMap() {
+        Map<String,Object> map = new LinkedHashMap<String,Object>();
+
+        Runtime rt = Runtime.getRuntime();
+        map.put("freeMemory", rt.freeMemory());
+        map.put("maxMemory", rt.maxMemory());
+        map.put("totalMemory", rt.totalMemory());
+        map.put("availableProcessors", rt.availableProcessors());
+        
+        return map;
+    }
+}
\ No newline at end of file

Propchange: geronimo/gshell/trunk/gshell-wisdom/gshell-wisdom-core/src/main/java/org/apache/geronimo/gshell/wisdom/meta/RuntimeContent.java
------------------------------------------------------------------------------
    svn:eol-style = native

Propchange: geronimo/gshell/trunk/gshell-wisdom/gshell-wisdom-core/src/main/java/org/apache/geronimo/gshell/wisdom/meta/RuntimeContent.java
------------------------------------------------------------------------------
    svn:keywords = Date Author Id Revision HeadURL

Propchange: geronimo/gshell/trunk/gshell-wisdom/gshell-wisdom-core/src/main/java/org/apache/geronimo/gshell/wisdom/meta/RuntimeContent.java
------------------------------------------------------------------------------
    svn:mime-type = text/plain

Added: geronimo/gshell/trunk/gshell-wisdom/gshell-wisdom-core/src/main/java/org/apache/geronimo/gshell/wisdom/meta/SystemEnvironmentContent.java
URL: http://svn.apache.org/viewvc/geronimo/gshell/trunk/gshell-wisdom/gshell-wisdom-core/src/main/java/org/apache/geronimo/gshell/wisdom/meta/SystemEnvironmentContent.java?rev=701789&view=auto
==============================================================================
--- geronimo/gshell/trunk/gshell-wisdom/gshell-wisdom-core/src/main/java/org/apache/geronimo/gshell/wisdom/meta/SystemEnvironmentContent.java (added)
+++ geronimo/gshell/trunk/gshell-wisdom/gshell-wisdom-core/src/main/java/org/apache/geronimo/gshell/wisdom/meta/SystemEnvironmentContent.java Sun Oct  5 06:08:45 2008
@@ -0,0 +1,37 @@
+/*
+ * Licensed to the Apache Software Foundation (ASF) under one
+ * or more contributor license agreements.  See the NOTICE file
+ * distributed with this work for additional information
+ * regarding copyright ownership.  The ASF licenses this file
+ * to you under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance
+ * with the License.  You may obtain a copy of the License at
+ *
+ *  http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ * KIND, either express or implied.  See the License for the
+ * specific language governing permissions and limitations
+ * under the License.
+ */
+
+package org.apache.geronimo.gshell.wisdom.meta;
+
+import org.apache.geronimo.gshell.vfs.provider.meta.MetaDataContent;
+
+import java.util.Map;
+
+/**
+ * {@link MetaDataContent} to return the contents of {@link System#getenv}.
+ *
+ * @version $Rev$ $Date$
+ */
+public class SystemEnvironmentContent
+    extends MapContentSupport<String,String>
+{
+    protected Map<String, String> getMap() {
+        return System.getenv();
+    }
+}
\ No newline at end of file

Propchange: geronimo/gshell/trunk/gshell-wisdom/gshell-wisdom-core/src/main/java/org/apache/geronimo/gshell/wisdom/meta/SystemEnvironmentContent.java
------------------------------------------------------------------------------
    svn:eol-style = native

Propchange: geronimo/gshell/trunk/gshell-wisdom/gshell-wisdom-core/src/main/java/org/apache/geronimo/gshell/wisdom/meta/SystemEnvironmentContent.java
------------------------------------------------------------------------------
    svn:keywords = Date Author Id Revision HeadURL

Propchange: geronimo/gshell/trunk/gshell-wisdom/gshell-wisdom-core/src/main/java/org/apache/geronimo/gshell/wisdom/meta/SystemEnvironmentContent.java
------------------------------------------------------------------------------
    svn:mime-type = text/plain

Copied: geronimo/gshell/trunk/gshell-wisdom/gshell-wisdom-core/src/main/java/org/apache/geronimo/gshell/wisdom/meta/SystemPropertiesContent.java (from r701779, geronimo/gshell/trunk/gshell-wisdom/gshell-wisdom-core/src/main/java/org/apache/geronimo/gshell/wisdom/meta/SystemPropertiesMetaData.java)
URL: http://svn.apache.org/viewvc/geronimo/gshell/trunk/gshell-wisdom/gshell-wisdom-core/src/main/java/org/apache/geronimo/gshell/wisdom/meta/SystemPropertiesContent.java?p2=geronimo/gshell/trunk/gshell-wisdom/gshell-wisdom-core/src/main/java/org/apache/geronimo/gshell/wisdom/meta/SystemPropertiesContent.java&p1=geronimo/gshell/trunk/gshell-wisdom/gshell-wisdom-core/src/main/java/org/apache/geronimo/gshell/wisdom/meta/SystemPropertiesMetaData.java&r1=701779&r2=701789&rev=701789&view=diff
==============================================================================
--- geronimo/gshell/trunk/gshell-wisdom/gshell-wisdom-core/src/main/java/org/apache/geronimo/gshell/wisdom/registry/CommandResolverImpl.java (original)
+++ geronimo/gshell/trunk/gshell-wisdom/gshell-wisdom-core/src/main/java/org/apache/geronimo/gshell/wisdom/registry/CommandResolverImpl.java Sun Oct  5 06:08:45 2008
@@ -30,6 +30,7 @@
 import org.apache.geronimo.gshell.spring.BeanContainer;
 import org.apache.geronimo.gshell.spring.BeanContainerAware;
 import org.apache.geronimo.gshell.wisdom.registry.AliasCommand;
+import org.apache.geronimo.gshell.vfs.FileSystemAccess;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 import org.springframework.beans.factory.annotation.Autowired;
@@ -51,6 +52,9 @@
     private AliasRegistry aliasRegistry;
 
     @Autowired
+    private FileSystemAccess fileSystemAccess;
+
+    @Autowired
     private CommandLineExecutor executor;
 
     private BeanContainer container;
@@ -71,13 +75,6 @@
         // FIXME: For now just ask for the named stuff, eventually need a better path parser and lookup thingy
         //
 
-        //
-        // TODO: Implement a gshell:// VFS file-system and have a gshell://commands tree which contains all commands
-        //       registered, or rather files which contain accessors to the commands, probably set teh command as an attribute?
-        //
-        //       Can also have a gshell://plugins tree which contains those details as well.
-        //
-
         Command command;
 
         assert aliasRegistry != null;

Modified: geronimo/gshell/trunk/gshell-wisdom/gshell-wisdom-core/src/main/resources/META-INF/spring/components.xml
URL: http://svn.apache.org/viewvc/geronimo/gshell/trunk/gshell-wisdom/gshell-wisdom-core/src/main/resources/META-INF/spring/components.xml?rev=701789&r1=701788&r2=701789&view=diff
==============================================================================
--- geronimo/gshell/trunk/gshell-wisdom/gshell-wisdom-core/src/main/resources/META-INF/spring/components.xml (original)
+++ geronimo/gshell/trunk/gshell-wisdom/gshell-wisdom-core/src/main/resources/META-INF/spring/components.xml Sun Oct  5 06:08:45 2008
@@ -58,9 +58,7 @@
 
     <bean id="commandsCompleter" class="org.apache.geronimo.gshell.wisdom.completer.CommandsCompleter"/>
 
-    <bean class="org.apache.geronimo.gshell.wisdom.meta.MetaDataInstaller">
-        
-    </bean>
+    <bean class="org.apache.geronimo.gshell.wisdom.meta.MetaDataInstaller"/>
 
     <bean id="pluginTemplate" class="org.apache.geronimo.gshell.wisdom.plugin.PluginImpl" abstract="true">
         <property name="activationRules">
--- geronimo/gshell/trunk/gshell-support/gshell-vfs-meta/src/main/java/org/apache/geronimo/gshell/vfs/provider/meta/MetaDataRegistry.java (original)
+++ geronimo/gshell/trunk/gshell-support/gshell-vfs-meta/src/main/java/org/apache/geronimo/gshell/vfs/provider/meta/MetaDataContent.java Sun Oct  5 06:08:45 2008
@@ -19,20 +19,16 @@
 
 package org.apache.geronimo.gshell.vfs.provider.meta;
 
-import org.apache.commons.vfs.FileName;
-
 /**
  * Meta data registry.
  *
  * @version $Rev$ $Date$
  */
-public interface MetaDataRegistry
+public interface MetaDataContent
 {
-    void registerData(FileName name, MetaData data);
-
-    void removeData(FileName name);
-
-    MetaData lookupData(FileName name) /* throws MetaFileDataRegistryException */;
+    byte[] getBuffer();
 
-    boolean containsData(FileName name);
+    //
+    // TODO: Expose the content-type and encoding?  Need to provide custom handling of FileContent and FileContentInfo stuff to use.
+    //
 }
\ No newline at end of file

Propchange: geronimo/gshell/trunk/gshell-support/gshell-vfs-meta/src/main/java/org/apache/geronimo/gshell/vfs/provider/meta/MetaDataContent.java
------------------------------------------------------------------------------
    svn:eol-style = native

Propchange: geronimo/gshell/trunk/gshell-support/gshell-vfs-meta/src/main/java/org/apache/geronimo/gshell/vfs/provider/meta/MetaDataContent.java
------------------------------------------------------------------------------
    svn:keywords = Date Author Id Revision HeadURL

Propchange: geronimo/gshell/trunk/gshell-support/gshell-vfs-meta/src/main/java/org/apache/geronimo/gshell/vfs/provider/meta/MetaDataContent.java
------------------------------------------------------------------------------
    svn:mergeinfo = 

Propchange: geronimo/gshell/trunk/gshell-support/gshell-vfs-meta/src/main/java/org/apache/geronimo/gshell/vfs/provider/meta/MetaDataContent.java
------------------------------------------------------------------------------
    svn:mime-type = text/plain
@@ -19,20 +19,16 @@
 /**
- * Meta data registry.
+ * Meta data content.
  *
  * @version $Rev$ $Date$

Modified: geronimo/gshell/trunk/gshell-support/gshell-vfs-meta/src/main/java/org/apache/geronimo/gshell/vfs/provider/meta/MetaDataRegistryConfigurer.java
URL: http://svn.apache.org/viewvc/geronimo/gshell/trunk/gshell-support/gshell-vfs-meta/src/main/java/org/apache/geronimo/gshell/vfs/provider/meta/MetaDataRegistryConfigurer.java?rev=701789&r1=701788&r2=701789&view=diff
==============================================================================
--- geronimo/gshell/trunk/gshell-wisdom/gshell-wisdom-core/src/main/java/org/apache/geronimo/gshell/wisdom/meta/SystemPropertiesMetaData.java (original)
+++ geronimo/gshell/trunk/gshell-wisdom/gshell-wisdom-core/src/main/java/org/apache/geronimo/gshell/wisdom/meta/SystemPropertiesContent.java Sun Oct  5 06:08:45 2008
@@ -19,39 +19,19 @@
 
 package org.apache.geronimo.gshell.wisdom.meta;
 
-import org.apache.geronimo.gshell.vfs.provider.meta.MetaData;
-import org.apache.commons.vfs.FileName;
-import org.apache.commons.vfs.FileType;
+import org.apache.geronimo.gshell.vfs.provider.meta.MetaDataContent;
 
-import java.io.ByteArrayOutputStream;
-import java.io.IOException;
-import java.util.Properties;
+import java.util.Map;
 
 /**
  * {@link MetaData} to return the contents of {@link System#getProperties}.
  *
  * @version $Rev$ $Date$
  */
-public class SystemPropertiesMetaData
-    extends MetaData
+public class SystemPropertiesContent
+    extends MapContentSupport<Object,Object>
 {
-    public SystemPropertiesMetaData(final FileName name) {
-        super(name, FileType.FILE);
-    }
-
-    @Override
-    public byte[] getBuffer() {
-        ByteArrayOutputStream output = new ByteArrayOutputStream();
-
-        Properties props = System.getProperties();
-
-        try {
-            props.store(output, "System Properties");
-        }
-        catch (IOException e) {
-            throw new RuntimeException(e);
-        }
-
-        return output.toByteArray();
+    protected Map<Object, Object> getMap() {
+        return System.getProperties();
     }
 }
\ No newline at end of file

Propchange: geronimo/gshell/trunk/gshell-wisdom/gshell-wisdom-core/src/main/java/org/apache/geronimo/gshell/wisdom/meta/SystemPropertiesContent.java
------------------------------------------------------------------------------
    svn:eol-style = native

Propchange: geronimo/gshell/trunk/gshell-wisdom/gshell-wisdom-core/src/main/java/org/apache/geronimo/gshell/wisdom/meta/SystemPropertiesContent.java
------------------------------------------------------------------------------
    svn:keywords = Date Author Id Revision HeadURL

Propchange: geronimo/gshell/trunk/gshell-wisdom/gshell-wisdom-core/src/main/java/org/apache/geronimo/gshell/wisdom/meta/SystemPropertiesContent.java
------------------------------------------------------------------------------
    svn:mime-type = text/plain
@@ -19,39 +19,19 @@
 
 /**
- * {@link MetaData} to return the contents of {@link System#getProperties}.
+ * {@link MetaDataContent} to return the contents of {@link System#getProperties}.
  *
  * @version $Rev$ $Date$

Modified: geronimo/gshell/trunk/gshell-wisdom/gshell-wisdom-core/src/main/java/org/apache/geronimo/gshell/wisdom/registry/CommandResolverImpl.java
URL: http://svn.apache.org/viewvc/geronimo/gshell/trunk/gshell-wisdom/gshell-wisdom-core/src/main/java/org/apache/geronimo/gshell/wisdom/registry/CommandResolverImpl.java?rev=701789&r1=701788&r2=701789&view=diff
==============================================================================